#!/bin/bash

log_file=/linuxcash/logs/current/upgrade_to_jammy.log

set -eu

log()
{
    echo `date` "$1"
}

NOW="false"
while [ $# -gt 0 ]
do
	case $1 in
		-h|--help)
			echo "Производит обновление с Ubuntu 18.04 на Ubuntu 22.04"
			echo "Параметры:"
			echo "	-h|--help        Помощь"
			echo "	-n|--now|now     Выполнить обновление сразу, не ожидая перезапуска кассы"
			echo -e "\nПример: ${0##*/} -n"
			exit 0
			;;
		-n|--now|now)
			NOW="true"
			;;
		*)
			echo -e "\x1b[1;31mНеизвестный параметр \"$1\"\x1b[0m"
            exit 1
			;;
	esac
	shift
done

export DATA_PREFIX=/var/lib/artix-upgrade
export CONTINUE_FLAG="$DATA_PREFIX/continue"

mkdir -p "$DATA_PREFIX"/stages
rm -f "$CONTINUE_FLAG"

if [ "$NOW" != "true" ]
then
    touch "$CONTINUE_FLAG"
    UPDATE_MESSAGE="Обновление запланировано при следующем перезапуске кассы"
    log "$UPDATE_MESSAGE" | tee -a "$log_file"
    if pgrep -x artix-gui &> /dev/null ; then
        NOTOFY_FILE="/linuxcash/cash/data/tmp/notification.json"
        echo "{\"message\":\"$UPDATE_MESSAGE\"}" > $NOTOFY_FILE.tmp
        mv $NOTOFY_FILE.tmp $NOTOFY_FILE
    fi
    exit 0
fi

# Отключаем диалоги
export DEBIAN_FRONTEND=noninteractive

export OLD_DISTRO=bionic
export OLD_NUMBER=18.04
export NEW_DISTRO=jammy
export NEW_NUMBER=22.04
export NEW_KVER=^6\.[0-9]+\.[0-9]+-[0-9]+-generic$

export LIB_PREFIX=/usr/lib/artix-upgrade

_reboot() {
    if [ -d "$DATA_PREFIX" ]; then
        touch "$DATA_PREFIX"/stages/"$script".completed
        touch "$CONTINUE_FLAG"
    fi
    systemctl --force reboot
    return 1
}

{
    for script in $(ls -1 "$LIB_PREFIX"/stages); do
        if [ ! -e "$DATA_PREFIX"/stages/"$script".completed ]; then
            source "$LIB_PREFIX"/stages/"$script"

            [ -d "$DATA_PREFIX"/stages ] && touch "$DATA_PREFIX"/stages/"$script".completed
        fi
    done
    log "Обновление выполнено успешно"
    printf "\nЧерез 30 секунд будет выполнена перезагрузка. Нажмите Ctrl+C для отмены\n"
    sleep 30
    _reboot
} |& tee -a "$log_file"
