#!/bin/bash

log "Подготовка к обновлению"

log "Проверяем конфигурацию загрузчика GRUB"

AVAILABLE_DEVICES=$(grub-mkdevicemap -m - | grep -v "^(fd[0-9]\+)" | cut -f2)
GRUB_INSTALL_DEVICES=$(debconf-show grub-pc | grep "grub-pc/install_devices:" | cut -d " " -f1,2 --complement)

reconfigure()
{
    DEVICE=$(echo $AVAILABLE_DEVICES | cut -d " " -f1)
    log "В качестве загрузочного устройства GRUB будет установлен диск '$DEVICE'"
    echo "grub-pc grub-pc/install_devices string $DEVICE" | debconf-set-selections
    return 0
}

if [ -z "${GRUB_INSTALL_DEVICES}" ]; then
    log "Ошибка конфигурации. Не назначено ни одного загрузочного устройства"
    reconfigure
fi

for GRUB_INSTALL_DISK in ${GRUB_INSTALL_DEVICES/','/' '}; do
    NEEDS_RECONFIGURATION=true

    for AVAILABLE_DISK in $AVAILABLE_DEVICES; do
        if [ -n "$(echo $GRUB_INSTALL_DISK | grep $AVAILABLE_DISK)" ]; then
            log "Диск '$GRUB_INSTALL_DISK' доступен и помечен как загрузочный"
            NEEDS_RECONFIGURATION=false
            break;
        fi
    done

    if ( $NEEDS_RECONFIGURATION ); then
        log "Ошибка конфигурации. Диск '$GRUB_INSTALL_DISK' помечен как загрузочный, но он отсутствует в системе"
        reconfigure
    fi
done
